@@ -33,3 +33,15 @@ class TrackerActiveError(Exception):
 
 class TrackerNotActiveError(Exception):
     pass
+
+
+class CannotTrackError(Exception):
+    pass
+
+
+class IncorrectSuffixError(Exception):
+    pass
+
+
+class ContextActiveError(Exception):
+    pass
