@@ -1,4 +1,5 @@
 import html
+import shutil
 import textwrap
 from dataclasses import dataclass
 from pathlib import Path
@@ -6,16 +7,19 @@ from textwrap import indent
 from typing import Literal, Optional, Tuple, Union
 
 from mdutils.tools.TextUtils import TextUtils
-from mkreports.settings import Settings
+from mkreports.md_proxy import register_md
 
-from .base import MdObj
-from .file import File
+from .base import MdObj, MdOut
+from .file import File, relpath_html
+from .settings import Settings
 from .text import SpacedText, Text
 
 
+@register_md("Admonition")
 @dataclass
 class Admonition(MdObj):
     text: Union[Text, MdObj]
+    javascript_path: Path
     title: Optional[str] = None
     kind: Literal[
         "note",
@@ -30,10 +34,27 @@ class Admonition(MdObj):
         "bug",
         "example",
         "quote",
+        "code",
     ] = "note"
     collapse: bool = False
 
-    def req_settings(self) -> Settings:
+    def __post_init__(self):
+        if self.kind == "code":
+            # create a css file that creates a 'code' admonition
+            self.css_path = self.javascript_path / "code_admonition.css"
+            self.javascript_path.mkdir(parents=True, exist_ok=True)
+            shutil.copy(
+                Path(__file__).parent / "code_admonition.css",
+                self.css_path,
+            )
+
+    def to_markdown(self, page_path: Path, **kwargs) -> MdOut:
+        # if code-admonition, we need to load additional css
+        if self.kind == "code":
+            rel_css_path = relpath_html(self.css_path, page_path)
+            page_settings = dict(css=[rel_css_path])
+        else:
+            page_settings = {}
         cont_settings = Settings(
             mkdocs={
                 "markdown_extensions": [
@@ -41,45 +62,38 @@ class Admonition(MdObj):
                     "pymdownx.details",
                     "pymdownx.superfences",
                 ]
-            }
+            },
+            page=page_settings,
         )
         if isinstance(self.text, MdObj):
-            return cont_settings + self.text.req_settings()
+            admon_text, back, settings = self.text.to_markdown(**kwargs)
+            settings = cont_settings + settings
         else:
-            return cont_settings
-
-    def backmatter(self, page_path: Optional[Path] = None):
-        if isinstance(self.text, MdObj):
-            return self.text.backmatter(page_path)
-        else:
-            return SpacedText("")
-
-    def to_markdown(self, page_path: Optional[Path] = None) -> SpacedText:
-        if isinstance(self.text, MdObj):
-            admon_text = self.text.to_markdown(page_path)
-        else:
-            admon_text = str(self.text)
+            admon_text, back, settings = str(self.text), SpacedText(), cont_settings
 
         if self.title is None:
             title_md = ""
         else:
             title_md = f'"{self.title}"'
 
-        return (
-            SpacedText(
+        return MdOut(
+            body=SpacedText(
                 f"{'???' if self.collapse else '!!!'} {self.kind} {title_md}",
                 (2, 2),
             )
-            + SpacedText(indent(str(admon_text), "    "), (2, 2))
+            + SpacedText(indent(str(admon_text), "    "), (2, 2)),
+            back=back,
+            settings=settings,
         )
 
 
+@register_md("Tab")
 @dataclass
 class Tab(MdObj):
     text: Union[Text, MdObj]
     title: Optional[str] = None
 
-    def req_settings(self) -> Settings:
+    def to_markdown(self, **kwargs) -> MdOut:
         tab_settings = Settings(
             mkdocs={
                 "markdown_extensions": [
@@ -89,32 +103,25 @@ class Tab(MdObj):
             }
         )
         if isinstance(self.text, MdObj):
-            return tab_settings + self.text.req_settings()
+            tab_text, back, settings = self.text.to_markdown(**kwargs)
+            settings = tab_settings + settings
         else:
-            return tab_settings
-
-    def backmatter(self, page_path: Optional[Path] = None):
-        if isinstance(self.text, MdObj):
-            return self.text.backmatter(page_path)
-        else:
-            return SpacedText("")
-
-    def to_markdown(self, page_path: Optional[Path] = None) -> SpacedText:
-        if isinstance(self.text, MdObj):
-            tab_text = self.text.to_markdown(page_path)
-        else:
-            tab_text = str(self.text)
+            tab_text, back, settings = str(self.text), SpacedText(), tab_settings
 
         if self.title is not None:
             title_text = html.escape(self.title)
         else:
             title_text = ""
 
-        return SpacedText(f'=== "{title_text}"', (2, 2)) + SpacedText(
-            indent(str(tab_text), "    "), (2, 2)
+        return MdOut(
+            body=SpacedText(f'=== "{title_text}"', (2, 2))
+            + SpacedText(indent(str(tab_text), "    "), (2, 2)),
+            back=back,
+            settings=settings,
         )
 
 
+@register_md("Code")
 @dataclass(frozen=True)
 class Code(MdObj):
     """Wrapper class for code."""
@@ -126,15 +133,8 @@ class Code(MdObj):
     language: Optional[str] = "python"
     dedent: bool = True
 
-    def req_settings(self):
-        settings = Settings(
-            mkdocs=dict(
-                markdown_extensions=[{"pymdownx.highlight": dict(use_pygments=True)}]
-            )
-        )
-        return settings
-
-    def to_markdown(self, page_path: Optional[Path] = None) -> SpacedText:
+    def to_markdown(self, **kwargs) -> MdOut:
+        del kwargs
         annots = ""
         if self.language is not None:
             annots = annots + self.language
@@ -156,11 +156,20 @@ class Code(MdObj):
         if hl_lines is not None:
             annots = annots + f' hl_lines="{hl_lines[0]}-{hl_lines[1]}"'
 
-        return SpacedText(
-            TextUtils.insert_code(textwrap.dedent(self.code), annots), (2, 2)
+        settings = Settings(
+            mkdocs=dict(
+                markdown_extensions=[{"pymdownx.highlight": dict(use_pygments=True)}]
+            )
+        )
+        return MdOut(
+            body=SpacedText(
+                TextUtils.insert_code(textwrap.dedent(self.code), annots), (2, 2)
+            ),
+            settings=settings,
         )
 
 
+@register_md("CodeFile")
 class CodeFile(File):
     """
     Code block with the content of a file.
@@ -186,19 +195,8 @@ class CodeFile(File):
         self.hl_lines = hl_lines
         self.language = language
 
-    def req_settings(self):
-        settings = Settings(mkdocs=dict(markdown_extensions="pymdownx.snippets"))
-        settings = Settings(
-            mkdocs=dict(
-                markdown_extensions=[
-                    "pymdownx.snippets",
-                    {"pymdownx.highlight": dict(use_pygments=True)},
-                ]
-            )
-        )
-        return settings
-
-    def to_markdown(self, page_path: Optional[Path] = None) -> SpacedText:
+    def to_markdown(self, **kwargs) -> MdOut:
+        del kwargs
         annots = ""
         if self.language is not None:
             annots = annots + self.language
@@ -209,9 +207,20 @@ class CodeFile(File):
         if hl_lines is not None:
             annots = annots + f' hl_lines="{hl_lines[0]}-{hl_lines[1]}"'
 
-        return SpacedText(
-            TextUtils.insert_code(
-                f"--8<-- '{self.path.relative_to(self.report_path)}'", annots
+        settings = Settings(
+            mkdocs=dict(
+                markdown_extensions=[
+                    "pymdownx.snippets",
+                    {"pymdownx.highlight": dict(use_pygments=True)},
+                ]
+            )
+        )
+        return MdOut(
+            body=SpacedText(
+                TextUtils.insert_code(
+                    f"--8<-- '{self.path.relative_to(self.report_path)}'", annots
+                ),
+                (2, 2),
             ),
-            (2, 2),
+            settings=settings,
         )
