@@ -1,18 +1,18 @@
-from pathlib import Path
-from typing import Optional
+from mkreports.md_proxy import register_md
 
-from mkreports.settings import Settings
-
-from .base import MdObj
+from .base import MdObj, MdOut
+from .settings import Settings
 from .text import SpacedText
 
 
+@register_md("Docstring")
 class Docstring(MdObj):
     def __init__(self, obj_name: str) -> None:
         super().__init__()
         self.obj_name = obj_name
 
-    def req_settings(self) -> Settings:
+    def to_markdown(self, **kwargs) -> MdOut:
+        del kwargs
         cont_settings = Settings(
             mkdocs={
                 "plugins": [
@@ -21,7 +21,6 @@ class Docstring(MdObj):
                 ]
             }
         )
-        return cont_settings
-
-    def to_markdown(self, page_path: Optional[Path] = None):
-        return SpacedText(f"::: {self.obj_name}", (2, 2))
+        return MdOut(
+            body=SpacedText(f"::: {self.obj_name}", (2, 2)), settings=cont_settings
+        )
